pub enum KeySegment {
Key(String),
Index(usize),
Attribute(String),
}Expand description
A segment of a configuration key path.
Key segments represent individual components of a key path:
Key: A named field (e.g.,.database.url)Index: An array index (e.g.,.items[0])Attribute: An attribute name (e.g.,@type)
Variants
Key(String)
A named key segment.
Index(usize)
An array index segment.
Attribute(String)
An attribute name segment.
Implementations
Sourceimpl KeySegment
impl KeySegment
Sourcepub const fn as_index(&self) -> Option<usize>
pub const fn as_index(&self) -> Option<usize>
Returns the index value if this is an index segment.
Sourcepub fn as_attribute(&self) -> Option<&str>
pub fn as_attribute(&self) -> Option<&str>
Returns the attribute name if this is an attribute segment.
Sourcepub fn into_key(self) -> Option<String>
pub fn into_key(self) -> Option<String>
Consumes this segment and returns the key value if it was a key segment.
Sourcepub fn into_index(self) -> Option<usize>
pub fn into_index(self) -> Option<usize>
Consumes this segment and returns the index value if it was an index segment.
Sourcepub fn into_attribute(self) -> Option<String>
pub fn into_attribute(self) -> Option<String>
Consumes this segment and returns the attribute name if it was an attribute segment.